R/change_observations.R
ChangeObservations.RdUsing a fitted Dirichlet process object include new data. The new data will be assigned to the best fitting cluster for each point.
ChangeObservations(dpobj, newData)Changed Dirichlet process object
y <- rnorm(10)
dp <- DirichletProcessGaussian(y)
dp <- ChangeObservations(dp, rnorm(10))