R/cluster_label_predict.R
ClusterLabelPredict.RdGiven a fitted Dirichlet process object and some new data use this function to predict what clusters the new data belong to and associated cluster parameters.
ClusterLabelPredict(dpobj, newData)A list of the predicted cluster labels of some new unseen data.
y <- rnorm(10)
dp <- DirichletProcessGaussian(y)
dp <- Fit(dp, 5)
newY <- rnorm(10, 1)
pred <- ClusterLabelPredict(dp, newY)