R/dirichlet_process_beta.R
DirichletProcessBeta.RdCreate a Dirichlet process object using the mean and scale parameterisation of the Beta distribution bounded on \((0, maxY)\).
Data for which to be modelled.
End point of the data
Prior parameters of the base measure \((\alpha _0, \beta _0)\).
Prior parameters for the concentration parameter. See also UpdateAlpha.
Step size for Metropolis Hastings sampling algorithm.
Hyper-prior parameters for the prior distributions of the base measure parameters \((a, b)\).
Logical, control the level of on screen output.
Number of Metropolis-Hastings samples to perform for each cluster update.
Dirichlet process object
\(G_0 (\mu , \nu | maxY, \alpha _0 , \beta _0) = U(\mu | 0, maxY) \mathrm{Inv-Gamma} (\nu | \alpha _0, \beta _0)\).
The parameter \(\beta _0\) also has a prior distribution \(\beta _0 \sim \mathrm{Gamma} (a, b)\) if the user selects Fit(...,updatePrior=TRUE).