Fit a Hidden Markov Dirichlet Process Model
# S3 method for class 'markov'
Fit(dpObj, its, updatePrior = F, progressBar = F)
Arguments
- dpObj
Initialised Dirichlet Process object
- its
Number of iterations to use
- updatePrior
Logical flag, defaults to FAlSE. Set whether the parameters of the base measure are updated.
- progressBar
Logical flag indicating whether to display a progress bar.
Value
A Dirichlet Process object with the fitted cluster parameters and states.