R/posterior_clusters.R
PosteriorClusters.RdUsing the stick breaking representation the user can draw the posterior clusters and weights for a fitted Dirichlet Process.
See also PosteriorFunction.
PosteriorClusters(dpobj, ind)A list with the weights and cluster parameters that form the posterior of the Dirichlet process.
y <- rnorm(10)
dp <- DirichletProcessGaussian(y)
dp <- Fit(dp, 5)
postClusters <- PosteriorClusters(dp)