Print a Dirichlet process object. This will print some basic information about the dirichletprocess object.

# S3 method for class 'dirichletprocess'
print(x, param_summary = FALSE, digits = 2, ...)

Arguments

x

Dirichlet Process Object to print.

param_summary

If TRUE, print the overall averages of each parameter of the model. Note that this averages over all clusters and over all iterations, so it will only give a loose sense of the resulting DPM model.

digits

Integer; Number of digits to display.

...

Further arguments passed to or from other methods.

Examples

dp <- Fit(DirichletProcessGaussian(rnorm(10)), 100)
dp
#> Dirichlet process object run for 100 iterations.
#>                                      
#>   Mixing distribution          normal
#>   Base measure parameters  0, 1, 1, 1
#>   Alpha Prior parameters         2, 4
#>   Conjugacy                 conjugate
#>   Sample size                      10
#>                                      
#>   Mean number of clusters        3.65
#>   Median alpha                   0.70
#>